GPTwoSample plot — GPTwoSample 0.1.7a documentation

### Navigation

- index
- modules |
- next |
- previous |
- GPTwoSample 0.1.7a documentation »

# GPTwoSample plot

The easiest way to plot your results in an easy and convenient way.

## Plot GPTwoSample predictions

Module for easy plotting of GPTwoSample results.

`gptwosample.plot.plot_basic.plot_results` plots training data, as well as sausage_plots for a GPTwoSample experiment. You can give interval indices for plotting, if u chose

Created on Feb 10, 2011

@author: Max Zwiessele, Oliver Stegle

`gptwosample.plot.plot_basic.` `plot_results`(twosample_object, xlabel='input', ylabel='ouput', title=None, interval_indices=None, alpha=None, legend=True, replicate_indices=None, shift=None, *args, **kwargs)

  Plot the results given by last prediction.

  Two Instance Plots of comparing two groups to each other:

  Parameters:

  twosample_object : `gptwosample.twosample`
    GPTwoSample object, on which already ‘predict’ was called.

  Differential Groups:

  Non-Differential Groups:

  Returns:
    Proper rectangles for use in pylab.legend().

# .. automodule:: gptwosample.plot.interval # :members:

### Navigation

- index
- modules |
- next |
- previous |
- GPTwoSample 0.1.7a documentation »